@@ -1,8 +1,6 @@
 # --
 # Kernel/Language/bg.pm - provides bg language translation
-# Copyright (C) 2002 Vladimir Gerdjikov <gerdjikov at gerdjikovs.net>
-# --
-# $Id: bg.pm,v 1.17 2003/04/12 23:03:36 martin Exp $
+# Copyright (C) 2004 Vladimir Gerdjikov <gerdjikov at gerdjikovs.net>
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,7 +11,7 @@ package Kernel::Language::bg;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.17 $';
+$VERSION = '$Revision: 1.22.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 # --
 sub Data {
@@ -22,7 +20,7 @@ sub Data {
     my %Hash = ();
 
     # $$START$$
-    # Last translation Sun Apr 13 01:00:40 2003 by 
+    # Last translation Tue Feb 24 22:16:49 2004 by 
 
     # possible charsets
     $Self->{Charset} = ['cp1251', 'Windows-1251', ];
@@ -30,20 +28,24 @@ sub Data {
     $Self->{DateFormat} = '%D.%M.%Y %T';
     $Self->{DateFormatLong} = '%A %D %B %T %Y';
     $Self->{DateInputFormat} = '%D.%M.%Y - %T';
+    $Self->{DateInputFormatLong} = '';
 
     %Hash = (
     # Template: AAABase
       ' 2 minutes' => ' 2 ',
       ' 5 minutes' => ' 5 ',
       ' 7 minutes' => ' 7 ',
+      '(Click here to add)' => '',
       '10 minutes' => '10 ',
       '15 minutes' => '15 ',
       'AddLink' => '  ',
-      'AdminArea' => '-',
+      'Admin-Area' => '',
       'agent' => '',
+      'Agent-Area' => '',
       'all' => '',
       'All' => '',
       'Attention' => '',
+      'before' => '',
       'Bug Report' => '  ',
       'Cancel' => '',
       'change' => '',
@@ -55,18 +57,21 @@ sub Data {
       'customer' => '',
       'Customer Info' => ' ',
       'day' => '',
+      'day(s)' => '',
       'days' => '',
       'description' => '',
       'Description' => '',
-      'Dispatching by email To: field.' => '',
-      'Dispatching by selected Queue.' => '',
-      'Don\'t work with UserID 1 (System account)! Create new users!' => '   UserID 1 ( )!   ',
+      'Dispatching by email To: field.' => '   To:  .',
+      'Dispatching by selected Queue.' => '   .',
+      'Don\'t show closed Tickets' => '',
+      'Don\'t work with UserID 1 (System account)! Create new users!' => '   UserID 1 ( )!   .',
       'Done' => '.',
       'end' => '',
       'Error' => '',
       'Example' => '',
       'Examples' => '',
       'Facility' => '',
+      'FAQ-Area' => '',
       'Feature not active!' => '   ',
       'go' => '',
       'go!' => '!',
@@ -80,25 +85,29 @@ sub Data {
       'Invalid SessionID!' => ' SessionID!',
       'Language' => '',
       'Languages' => '',
+      'last' => '',
       'Line' => '',
       'Lite' => '',
-      'Login failed! Your username or password was entered incorrectly.' => ' !      !',
+      'Login failed! Your username or password was entered incorrectly.' => ' !   /   !',
       'Logout successful. Thank you for using OTRS!' => '  .  ,   .',
       'Message' => '',
       'minute' => '',
       'minutes' => '',
       'Module' => '',
       'Modulefile' => '-',
+      'month(s)' => '',
       'Name' => '',
+      'New Article' => '',
       'New message' => ' ',
       'New message!' => ' !',
       'No' => '',
       'no' => '',
-      'No entry found!' => '',
+      'No entry found!' => '  !',
       'No suggestions' => ' ',
       'none' => '',
       'none - answered' => ' - ',
       'none!' => '!',
+      'Normal' => '',
       'Off' => '',
       'off' => '',
       'On' => '',
@@ -108,13 +117,16 @@ sub Data {
       'Please answer this ticket(s) to get back to the normal queue view!' => ',    ()         !',
       'Please contact your admin' => ',     ',
       'please do not edit!' => ',  !',
+      'Please go away!' => '',
       'possible' => '',
+      'Preview' => '',
       'QueueView' => '  ',
       'reject' => '',
       'replace with' => ' ',
       'Reset' => '',
       'Salutation' => '',
-      'Session has timed out. Please log in again.' => '',
+      'Session has timed out. Please log in again.' => ',   .     .',
+      'Show closed Tickets' => '',
       'Signature' => '',
       'Sorry' => '',
       'Stats' => '',
@@ -122,22 +134,26 @@ sub Data {
       'submit' => '',
       'submit!' => '!',
       'system' => '',
-      'Take this User' => '',
+      'Take this User' => '  ',
       'Text' => '',
       'The recommended charset for your language is %s!' => '       %s',
       'Theme' => '',
       'There is no account with that login name.' => '    .',
       'Timeover' => '  ',
+      'To: (%s) replaced with database email!' => '',
       'top' => ' ',
       'update' => '',
+      'Update' => '',
       'update!' => '!',
       'User' => '',
       'Username' => ' ',
       'Valid' => '',
       'Warning' => '',
+      'week(s)' => '',
       'Welcome to OTRS' => '   OTRS',
       'Word' => '',
       'wrote' => '',
+      'year(s)' => '',
       'yes' => '',
       'Yes' => '',
       'You got new message!' => '  !',
@@ -159,29 +175,36 @@ sub Data {
       'Sep' => '',
 
     # Template: AAAPreferences
-      'Closed Tickets' => '',
+      'Closed Tickets' => ' ',
+      'CreateTicket' => '',
       'Custom Queue' => ' ',
       'Follow up notification' => '      ',
       'Frontend' => '-',
       'Mail Management' => '  ',
+      'Max. shown Tickets a page in Overview.' => '',
+      'Max. shown Tickets a page in QueueView.' => '',
       'Move notification' => '  ',
       'New ticket notification' => '   ',
       'Other Options' => ' ',
+      'PhoneView' => '  ',
       'Preferences updated successfully!' => '   ',
-      'QueueView refresh time' => '      ',
-      'Select your default spelling dictionary.' => '',
+      'QueueView refresh time' => '     ',
+      'Screen after new ticket' => '',
+      'Select your default spelling dictionary.' => '      ',
       'Select your frontend Charset.' => '   .',
       'Select your frontend language.' => '  .',
       'Select your frontend QueueView.' => '      .',
       'Select your frontend Theme.' => '   ',
       'Select your QueueView refresh time.' => '        .',
+      'Select your screen after creating a new ticket.' => '',
       'Send me a notification if a customer sends a follow up and I\'m the owner of this ticket.' => '  ,              ',
       'Send me a notification if a ticket is moved into a custom queue.' => '  ,        .',
       'Send me a notification if a ticket is unlocked by the system.' => '  ,      .',
       'Send me a notification if there is a new ticket in my custom queues.' => '  ,   ()     .',
-      'Show closed tickets.' => '',
-      'Spelling Dictionary' => '',
+      'Show closed tickets.' => '  ',
+      'Spelling Dictionary' => '    ',
       'Ticket lock timeout notification' => '      ',
+      'TicketZoom' => '',
 
     # Template: AAATicket
       '1 very low' => '1  ',
@@ -203,10 +226,10 @@ sub Data {
       'Compose' => '',
       'Created' => '',
       'Createtime' => '  ',
-      'email' => '',
-      'eMail' => '',
-      'email-external' => ' ',
-      'email-internal' => ' ',
+      'email' => '-',
+      'eMail' => '-',
+      'email-external' => ' -',
+      'email-internal' => ' -',
       'Forward' => '',
       'From' => '',
       'high' => '',
@@ -237,9 +260,10 @@ sub Data {
       'State' => '',
       'Subject' => '',
       'This is a' => ' ',
-      'This is a HTML email. Click here to show it.' => '    HTML .  ,     ',
+      'This is a HTML email. Click here to show it.' => '    HTML .  ,    ',
       'This message was written in a character set other than your own.' => '         ,  .',
       'Ticket' => '',
+      'Ticket "%s" created!' => '',
       'To' => '',
       'to open it in a new window.' => '     ',
       'unlock' => '',
@@ -260,47 +284,53 @@ sub Data {
       'Wed' => '',
 
     # Template: AdminAttachmentForm
-      'Add attachment' => '   ',
+      'Add' => '',
       'Attachment Management' => '   ',
-      'Change attachment settings' => '    ',
 
     # Template: AdminAutoResponseForm
       'Add auto response' => '   ',
       'Auto Response From' => '  ',
       'Auto Response Management' => '   ',
       'Change auto response settings' => '     ',
-      'Charset' => ' ',
       'Note' => '',
       'Response' => '',
       'to get the first 20 character of the subject' => '    20    ""',
       'to get the first 5 lines of the email' => '    5   ',
       'to get the from line of the email' => '     ',
       'to get the realname of the sender (if given)' => '       (  )',
-      'to get the ticket id of the ticket' => '',
+      'to get the ticket id of the ticket' => '     ',
       'to get the ticket number of the ticket' => '     ',
       'Type' => '',
       'Useable options' => ' ',
 
-    # Template: AdminCharsetForm
-      'Add charset' => '   ',
-      'Change system charset setting' => '    ',
-      'System Charset Management' => '   ',
-
     # Template: AdminCustomerUserForm
-      'Add customer user' => ' -',
-      'Change customer user settings' => '  - ',
       'Customer User Management' => '  -',
       'Customer user will be needed to to login via customer panels.' => '           ',
+      'Select source:' => '',
+      'Source' => '',
 
     # Template: AdminCustomerUserGeneric
 
+    # Template: AdminCustomerUserGroupChangeForm
+      'Change %s settings' => '  %s ',
+      'Customer User <-> Group Management' => '',
+      'Full read and write access to the tickets in this group/queue.' => '',
+      'If nothing is selected, then there are no permissions in this group (tickets will not be available for the user).' => '',
+      'Permission' => '',
+      'Read only access to the ticket in this group/queue.' => '',
+      'ro' => '',
+      'rw' => '',
+      'Select the user:group permissions.' => '',
+
+    # Template: AdminCustomerUserGroupForm
+      'Change user <-> group settings' => '   <->   ',
+
     # Template: AdminCustomerUserPreferencesGeneric
 
     # Template: AdminEmail
       'Admin-Email' => '  Admin',
       'Body' => '  ',
       'OTRS-Admin Info!' => '  OTRS-Admin',
-      'Permission' => '',
       'Recipents' => '',
       'send' => '',
 
@@ -308,29 +338,28 @@ sub Data {
       'Message sent to' => '   ',
 
     # Template: AdminGroupForm
-      'Add group' => '  ',
-      'Change group settings' => '   ',
       'Create new groups to handle access permissions for different groups of agent (e. g. purchasing department, support department, sales department, ...).' => '            (    "",  ""  ..)',
       'Group Management' => '  ',
       'It\'s useful for ASP solutions.' => '      ASP.',
-      'The admin group is to get in the admin area and the stats group to get stats area.' => ' admin  admin ,  stat   stat ',
+      'The admin group is to get in the admin area and the stats group to get stats area.' => ' admin   ,  stat     .',
 
     # Template: AdminLog
       'System Log' => ' ',
 
     # Template: AdminNavigationBar
-      'AdminEmail' => 'Admin ',
-      'AgentFrontend' => '-',
-      'Attachment <-> Response' => '',
+      'AdminEmail' => 'Admin -',
+      'Attachment <-> Response' => ' <->',
       'Auto Response <-> Queue' => '  <-> ',
       'Auto Responses' => ' ',
-      'Charsets' => ' ',
-      'Customer User' => ' ',
-      'Email Addresses' => ' ',
+      'Customer User' => '-',
+      'Customer User <-> Groups' => '',
+      'Email Addresses' => '- ',
       'Groups' => '',
       'Logout' => '',
       'Misc' => '',
-      'POP3 Account' => 'POP3 ',
+      'Notifications' => '',
+      'PostMaster Filter' => '',
+      'PostMaster POP3 Account' => '',
       'Responses' => '',
       'Responses <-> Queue' => ' <-> ',
       'Select Box' => ' ',
@@ -339,14 +368,19 @@ sub Data {
       'System' => '',
       'User <-> Groups' => ' <-> ',
 
+    # Template: AdminNotificationForm
+      'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => '',
+      'Notification Management' => '',
+      'Notifications are sent to an agent or a customer.' => '',
+      'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => '',
+      'Options of the current user who requested this action (e. g. &lt;OTRS_CURRENT_USERFIRSTNAME&gt;)' => '',
+      'Ticket owner options (e. g. &lt;OTRS_OWNER_USERFIRSTNAME&gt;)' => '',
+
     # Template: AdminPOP3Form
-      'Add POP3 Account' => '  POP3 ',
       'All incoming emails with one account will be dispatched in the selected queue!' => '           !',
-      'Change POP3 Account setting' => ' POP3   ',
       'Dispatching' => '',
       'Host' => '',
       'If your account is trusted, the x-otrs header (for priority, ...) will be used!' => '    ,     x-otrs ( ,  ..)!',
-      'Login' => '',
       'POP3 Account Management' => '  POP3 ',
       'Trusted' => '',
 
@@ -358,22 +392,20 @@ sub Data {
     # Template: AdminQueueForm
       '0 = no escalation' => '0 =  ',
       '0 = no unlock' => '0 =  ',
-      'Add queue' => '  ',
-      'Change queue settings' => '    ',
-      'Customer Move Notify' => '',
-      'Customer Owner Notify' => '',
-      'Customer State Notify' => '',
+      'Customer Move Notify' => '    ',
+      'Customer Owner Notify' => '  ',
+      'Customer State Notify' => '    ',
       'Escalation time' => '   (  )',
       'Follow up Option' => '   ',
       'If a ticket is closed and the customer sends a follow up the ticket will be locked for the old owner.' => '         ,       ',
       'If a ticket will not be answered in thos time, just only this ticket will be shown.' => '       ,      ',
       'If an agent locks a ticket and he/she will not send an answer within this time, the ticket will be unlock automatically. So the ticket is viewable for all other agents.' => '     ( )      ,     .         ',
       'Key' => '',
-      'OTRS sends an notification email to the customer if the ticket is moved.' => '',
-      'OTRS sends an notification email to the customer if the ticket owner has changed.' => '',
-      'OTRS sends an notification email to the customer if the ticket state has changed.' => '',
+      'OTRS sends an notification email to the customer if the ticket is moved.' => 'OTRS    -  ,    .',
+      'OTRS sends an notification email to the customer if the ticket owner has changed.' => 'OTRS    -  ,      .',
+      'OTRS sends an notification email to the customer if the ticket state has changed.' => 'OTRS    -  ,      .',
       'Queue Management' => '  ',
-      'Sub-Queue of' => '',
+      'Sub-Queue of' => '- ',
       'Systemaddress' => ' ',
       'The salutation for email answers.' => '    ',
       'The signature for email answers.' => '    ',
@@ -382,7 +414,6 @@ sub Data {
       'Will be the sender address of this queue for email answers.' => '          ',
 
     # Template: AdminQueueResponsesChangeForm
-      'Change %s settings' => '  %s ',
       'Std. Responses <-> Queue Management' => '  <->   ',
 
     # Template: AdminQueueResponsesForm
@@ -397,19 +428,17 @@ sub Data {
 
     # Template: AdminResponseForm
       'A response is default text to write faster answer (with default text) to customers.' => '    ,  ,   -   ',
-      'Add response' => '  ',
-      'Change response settings' => '    ',
       'Don\'t forget to add a new response a queue!' => '         !',
+      'Next state' => ' ',
       'Response Management' => '  ',
+      'The current ticket state is' => '',
 
     # Template: AdminSalutationForm
-      'Add salutation' => '  ',
-      'Change salutation settings' => '    ',
       'customer realname' => '  ',
-      'for agent firstname' => '  - ',
-      'for agent lastname' => '  - ',
-      'for agent login' => '',
-      'for agent user id' => '',
+      'for agent firstname' => '  ',
+      'for agent lastname' => '  ',
+      'for agent login' => '   ',
+      'for agent user id' => '   ID',
       'Salutation Management' => '  ',
 
     # Template: AdminSelectBoxForm
@@ -421,34 +450,32 @@ sub Data {
       'SQL' => 'SQL',
 
     # Template: AdminSession
+      'Agent' => '',
       'kill all sessions' => '    ',
+      'Overview' => '',
+      'Sessions' => '',
+      'Uniq' => '',
 
     # Template: AdminSessionTable
       'kill session' => '   ',
       'SessionID' => '  ',
 
     # Template: AdminSignatureForm
-      'Add signature' => '  ',
-      'Change signature settings' => '    ',
       'Signature Management' => '  ',
 
     # Template: AdminStateForm
-      'Add state' => '  ',
-      'Change system state setting' => '     ',
-      'State Type' => '',
+      'See also' => '',
+      'State Type' => ' ',
       'System State Management' => '   ',
+      'Take care that you also updated the default states in you Kernel/Config.pm!' => '',
 
     # Template: AdminSystemAddressForm
-      'Add system address' => '    ',
-      'All incoming emails with this "Email" (To:) will be dispatched in the selected queue!' => '      (:)      ',
-      'Change system address setting' => '     ',
-      'Email' => '',
+      'All incoming emails with this "Email" (To:) will be dispatched in the selected queue!' => '      (:)      .',
+      'Email' => '-',
       'Realname' => ' ',
       'System Email Addresses Management' => '    ',
 
     # Template: AdminUserForm
-      'Add user' => '  ',
-      'Change user settings' => '   ',
       'Don\'t forget to add a new user to groups!' => '        !',
       'Firstname' => '',
       'Lastname' => '',
@@ -456,14 +483,28 @@ sub Data {
       'User will be needed to handle tickets.' => '   ,       ',
 
     # Template: AdminUserGroupChangeForm
-      'Change  settings' => '  ',
+      'create' => '',
+      'move_into' => '',
+      'owner' => '',
+      'Permissions to change the ticket owner in this group/queue.' => '',
+      'Permissions to change the ticket priority in this group/queue.' => '',
+      'Permissions to create tickets in this group/queue.' => '',
+      'Permissions to move tickets into this group/queue.' => '',
+      'priority' => '',
       'User <-> Group Management' => ' <->   ',
 
     # Template: AdminUserGroupForm
-      'Change user <-> group settings' => '   <->   ',
 
     # Template: AdminUserPreferencesGeneric
 
+    # Template: AgentBook
+      'Address Book' => '',
+      'Discard all changes and return to the compose screen' => '           ',
+      'Return to the compose screen' => '     ',
+      'Search' => '',
+      'The message being composed has been closed.  Exiting.' => ',    . .',
+      'This window must be called from compose window' => '         ',
+
     # Template: AgentBounce
       'A message should have a To: recipient!' => '    : .. !',
       'Bounce ticket' => ' ',
@@ -476,6 +517,7 @@ sub Data {
 
     # Template: AgentClose
       ' (work units)' => ' ( )',
+      'A message should have a body!' => '',
       'A message should have a subject!' => '       ""!',
       'Close ticket' => ' ',
       'Close type' => ' ',
@@ -484,11 +526,11 @@ sub Data {
       'Note type' => '   ',
       'Options' => '',
       'Spell Check' => '  ',
-      'Time units' => '  ',
-      'You need to account time!' => '',
+      'Time units' => '   ',
+      'You need to account time!' => '      ',
 
     # Template: AgentCompose
-      'A message must be spell checked!' => '',
+      'A message must be spell checked!' => '      !',
       'Attach' => ' ',
       'Compose answer for ticket' => '     ',
       'for pending* states' => '   * ',
@@ -499,21 +541,26 @@ sub Data {
       'Back' => '',
       'Change customer of ticket' => '    ',
       'CustomerID' => ' ',
-      'Search Customer' => '',
-      'Set customer user and customer id of a ticket' => '',
+      'Search Customer' => '  ',
+      'Set customer user and customer id of a ticket' => '      ',
 
     # Template: AgentCustomerHistory
+      'All customer tickets.' => '',
       'Customer history' => '  ',
 
-    # Template: AgentCustomerHistoryTable
-
     # Template: AgentCustomerMessage
       'Follow up' => '  ',
-      'Next state' => '',
 
     # Template: AgentCustomerView
       'Customer Data' => '  ',
 
+    # Template: AgentEmailNew
+      'All Agents' => '',
+      'Clear From' => ' ',
+      'Compose Email' => '',
+      'Lock Ticket' => '',
+      'new ticket' => ' ',
+
     # Template: AgentForward
       'Article type' => ' ',
       'Date' => '',
@@ -523,7 +570,7 @@ sub Data {
       'Reply-To' => ' ',
 
     # Template: AgentFreeText
-      'Change free text of ticket' => '',
+      'Change free text of ticket' => '   ',
       'Value' => '',
 
     # Template: AgentHistoryForm
@@ -546,16 +593,19 @@ sub Data {
       'up' => '',
 
     # Template: AgentMailboxTicket
+      '"}' => '',
+      '"}","14' => '',
 
     # Template: AgentMove
-      'Move Ticket' => '',
-      'New Queue' => '',
-      'New user' => ' ',
+      'Move Ticket' => '  ',
+      'New Owner' => '',
+      'New Queue' => ' ',
+      'Previous Owner' => '',
+      'Queue ID' => '',
 
     # Template: AgentNavigationBar
       'Locked tickets' => ' ',
       'new message' => ' ',
-      'PhoneView' => '  ',
       'Preferences' => '',
       'Utilities' => ' ',
 
@@ -570,7 +620,7 @@ sub Data {
     # Template: AgentPending
       'Pending date' => '  - ',
       'Pending type' => '  - ',
-      'Pending!' => '',
+      'Pending!' => ' ',
       'Set Pending' => '  - ',
 
     # Template: AgentPhone
@@ -579,9 +629,6 @@ sub Data {
       'Phone call at %s' => '   %s',
 
     # Template: AgentPhoneNew
-      'Clear From' => '',
-      'create' => '',
-      'new ticket' => ' ',
 
     # Template: AgentPlain
       'ArticleID' => '  ',
@@ -602,16 +649,11 @@ sub Data {
 
     # Template: AgentPriority
       'Change priority of ticket' => '    ',
-      'New state' => ' ',
 
     # Template: AgentSpelling
       'Apply these changes' => '    ',
-      'Discard all changes and return to the compose screen' => '           ',
-      'Return to the compose screen' => '     ',
       'Spell Checker' => '  ',
       'spelling error(s)' => ' ()',
-      'The message being composed has been closed.  Exiting.' => ',    . .',
-      'This window must be called from compose window' => '         ',
 
     # Template: AgentStatusView
       'D' => 'D',
@@ -626,9 +668,13 @@ sub Data {
 
     # Template: AgentStatusViewTableNotAnswerd
 
+    # Template: AgentTicketLink
+      'Link' => '',
+      'Link to' => '',
+
     # Template: AgentTicketLocked
       'Ticket locked!' => '  !',
-      'Ticket unlock!' => '',
+      'Ticket unlock!' => '  !',
 
     # Template: AgentTicketPrint
       'by' => '',
@@ -636,15 +682,27 @@ sub Data {
     # Template: AgentTicketPrintHeader
       'Accounted time' => ' ',
       'Escalation in' => '   ',
-      'printed by' => '',
 
     # Template: AgentUtilSearch
-      'Article free text' => '  ',
-      'Fulltext search (e. g. "Mar*in" or "Baue*" or "martin+hallo")' => '  ( "Mar*in"  "Baue*"  "martin+hallo")',
-      'search' => '',
-      'search (e. g. 10*5155 or 105658*)' => ' ( 10*5155  105658*)',
-      'Ticket free text' => '  ',
-      'Ticket Search' => '',
+      '(e. g. 10*5155 or 105658*)' => '',
+      '(e. g. 234321)' => '',
+      '(e. g. U5150)' => '',
+      'and' => '',
+      'Customer User Login' => '',
+      'Delete' => '',
+      'Fulltext-Search in Article (e. g. "Mar*in" or "Baue*")' => '',
+      'No time settings.' => '',
+      'Profile' => '',
+      'Result Form' => '',
+      'Save Search-Profile as Template?' => '',
+      'Search-Template' => '',
+      'Select' => '',
+      'Ticket created' => '',
+      'Ticket created between' => '',
+      'Ticket Search' => '  ',
+      'TicketFreeText' => '',
+      'Times' => '',
+      'Yes, save it with name' => '',
 
     # Template: AgentUtilSearchByCustomerID
       'Customer history search' => '    ',
@@ -652,23 +710,37 @@ sub Data {
       'No * possible!' => '      *!',
 
     # Template: AgentUtilSearchNavBar
+      'Change search options' => '',
       'Results' => '',
+      'Search Result' => '',
       'Total hits' => '  ',
 
     # Template: AgentUtilSearchResult
+      '"}","15' => '',
+
+    # Template: AgentUtilSearchResultPrint
+
+    # Template: AgentUtilSearchResultPrintTable
+      '"}","30' => '',
+
+    # Template: AgentUtilSearchResultShort
+
+    # Template: AgentUtilSearchResultShortTable
+
+    # Template: AgentUtilSearchResultShortTableNotAnswered
 
     # Template: AgentUtilTicketStatus
-      'All closed tickets' => '',
+      'All closed tickets' => '  ',
       'All open tickets' => '  ',
-      'closed tickets' => '',
+      'closed tickets' => ' ',
       'open tickets' => ' ',
       'or' => '',
       'Provides an overview of all' => '    ',
       'So you see what is going on in your system.' => '    ',
 
     # Template: AgentZoomAgentIsCustomer
-      'Compose Follow up' => '',
-      'Your own Ticket' => '',
+      'Compose Follow up' => '   ',
+      'Your own Ticket' => '  ',
 
     # Template: AgentZoomAnswer
       'Compose Answer' => '  ',
@@ -682,17 +754,49 @@ sub Data {
       'Change queue' => '  ',
 
     # Template: AgentZoomHead
-      'Free Fields' => '',
+      'Free Fields' => ' ',
       'Print' => '',
 
     # Template: AgentZoomStatus
+      '"}","18' => '',
 
     # Template: CustomerCreateAccount
       'Create Account' => '  ',
+      'Login' => '',
 
     # Template: CustomerError
       'Traceback' => '',
 
+    # Template: CustomerFAQArticleHistory
+      'Edit' => '',
+      'FAQ History' => '',
+
+    # Template: CustomerFAQArticlePrint
+      'Category' => '',
+      'Keywords' => '',
+      'Last update' => '',
+      'Problem' => '',
+      'Solution' => '',
+      'Symptom' => '',
+
+    # Template: CustomerFAQArticleSystemHistory
+      'FAQ System History' => '',
+
+    # Template: CustomerFAQArticleView
+      'FAQ Article' => '',
+      'Modified' => '',
+
+    # Template: CustomerFAQOverview
+      'FAQ Overview' => '',
+
+    # Template: CustomerFAQSearch
+      'FAQ Search' => '',
+      'Fulltext' => '',
+      'Keyword' => '',
+
+    # Template: CustomerFAQSearchResult
+      'FAQ Search Result' => '',
+
     # Template: CustomerFooter
       'Powered by' => '  ',
 
@@ -715,7 +819,7 @@ sub Data {
 
     # Template: CustomerNavigationBar
       'Create new Ticket' => '   ',
-      'My Tickets' => ' ',
+      'FAQ' => '  ',
       'New Ticket' => ' ',
       'Ticket-Overview' => '-',
       'Welcome %s' => ' %s',
@@ -727,6 +831,7 @@ sub Data {
     # Template: CustomerPreferencesPassword
 
     # Template: CustomerStatusView
+      'My Tickets' => ' ',
 
     # Template: CustomerStatusViewTable
 
@@ -737,58 +842,89 @@ sub Data {
     # Template: Error
       'Click here to report a bug!' => ' ,      !',
 
+    # Template: FAQArticleDelete
+      'FAQ Delete' => '',
+      'You really want to delete this article?' => '',
+
+    # Template: FAQArticleForm
+      'Comment (internal)' => '',
+      'Filename' => '',
+      'Short Description' => '',
+
+    # Template: FAQArticleHistory
+
+    # Template: FAQArticlePrint
+
+    # Template: FAQArticleSystemHistory
+
+    # Template: FAQArticleView
+
+    # Template: FAQCategoryForm
+      'FAQ Category' => '',
+
+    # Template: FAQLanguageForm
+      'FAQ Language' => '',
+
+    # Template: FAQNavigationBar
+
+    # Template: FAQOverview
+
+    # Template: FAQSearch
+
+    # Template: FAQSearchResult
+
     # Template: Footer
-      'Top of Page' => '',
+      'Top of Page' => '  ',
 
     # Template: Header
 
     # Template: InstallerBody
-      'Create Database' => '',
-      'Drop Database' => '',
+      'Create Database' => '   ',
+      'Drop Database' => '  ',
       'Finished' => '',
-      'System Settings' => '',
-      'Web-Installer' => '',
+      'System Settings' => ' ',
+      'Web-Installer' => 'Web ',
 
     # Template: InstallerFinish
       'Admin-User' => '',
-      'After doing so your OTRS is up and running.' => '',
-      'Have a lot of fun!' => '',
-      'Restart your webserver' => '',
-      'Start page' => '',
-      'To be able to use OTRS you have to enter the following line in your command line (Terminal/Shell) as root.' => '',
-      'Your OTRS Team' => '',
+      'After doing so your OTRS is up and running.' => '   ,  OTRS   .',
+      'Have a lot of fun!' => ' !',
+      'Restart your webserver' => '  web ',
+      'Start page' => ' ',
+      'To be able to use OTRS you have to enter the following line in your command line (Terminal/Shell) as root.' => '     OTRS,    ,    root    (Terminal/Shell)  ',
+      'Your OTRS Team' => ' OTRS ',
 
     # Template: InstallerLicense
-      'accept license' => '',
-      'don\'t accept license' => '',
+      'accept license' => ' ',
+      'don\'t accept license' => '  ',
       'License' => '',
 
     # Template: InstallerStart
-      'Create new database' => '',
-      'DB Admin Password' => '',
-      'DB Admin User' => '',
-      'DB Host' => '',
-      'DB Type' => '',
-      'default \'hot\'' => '',
-      'Delete old database' => '',
+      'Create new database' => '    ',
+      'DB Admin Password' => '    ',
+      'DB Admin User' => '   ',
+      'DB Host' => '   ',
+      'DB Type' => '   ',
+      'default \'hot\'' => ' ',
+      'Delete old database' => '    ',
       'next step' => ' ',
-      'OTRS DB connect host' => '',
-      'OTRS DB Name' => '',
-      'OTRS DB Password' => '',
-      'OTRS DB User' => '',
-      'your MySQL DB should have a root password! Default is empty!' => '',
+      'OTRS DB connect host' => '   OTRS  ',
+      'OTRS DB Name' => '   OTRS  ',
+      'OTRS DB Password' => '  OTRS  ',
+      'OTRS DB User' => '  OTRS  ',
+      'your MySQL DB should have a root password! Default is empty!' => ' MYSQL        root .    !',
 
     # Template: InstallerSystem
-      '(Checks MX recordes of used email addresses by composing an answer. Don\'t use CheckMXRecord if your OTRS machine is behinde a dial-up line $!)' => '',
+      '(Checks MX recordes of used email addresses by composing an answer. Don\'t use CheckMXRecord if your OTRS machine is behinde a dial-up line $!)' => '( MX     -.   CheckMXRecord,   OTRS     ! ',
       '(Email of the system admin)' => '(   )',
       '(Full qualified domain name of your system)' => '(   (FQDN)  )',
       '(Logfile just needed for File-LogModule!)' => '(      File-LogModule)',
       '(The identify of the system. Each ticket number and each http session id starts with this number)' => '(  .       http     )',
-      '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '',
+      '(Ticket identifier. Some people want toset this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(  . : \'Ticket#\', \'Call#\' or \'MyTicket#\')',
       '(Used default language)' => '(   )',
       '(Used log backend)' => '(  )',
       '(Used ticket number format)' => '(     )',
-      'CheckMXRecord' => '',
+      'CheckMXRecord' => 'CheckMXRecord ( MX )',
       'Default Charset' => '   ',
       'Default Language' => '  ',
       'Logfile' => ' ',
@@ -798,6 +934,7 @@ sub Data {
       'SystemID' => ' ID',
       'Ticket Hook' => '  ',
       'Ticket Number Generator' => '    ',
+      'Use utf-8 it your database supports it!' => '',
       'Webfrontend' => 'Web-',
 
     # Template: Login
@@ -814,9 +951,11 @@ sub Data {
       'URL' => '',
 
     # Template: PrintHeader
+      'printed by' => ' ',
 
     # Template: QueueView
       'All tickets' => ' ',
+      'Page' => '',
       'Queues' => '',
       'Tickets available' => ' ',
       'Tickets shown' => ' ',
@@ -838,54 +977,38 @@ sub Data {
     # Template: Warning
 
     # Misc
-      '(Click here to add a group)' => '( ,     )',
-      '(Click here to add a queue)' => '( ,     )',
-      '(Click here to add a response)' => '( ,     )',
-      '(Click here to add a salutation)' => '( ,     )',
-      '(Click here to add a signature)' => '( ,     )',
-      '(Click here to add a system email address)' => '( ,      )',
-      '(Click here to add a user)' => '( ,     )',
-      '(Click here to add an auto response)' => '( ,      )',
-      '(Click here to add charset)' => '( ,      )',
-      '(Click here to add language)' => '( ,     )',
-      '(Click here to add state)' => '( ,       )',
       '(Ticket identifier. Some people want to set this to e. g. \'Ticket#\', \'Call#\' or \'MyTicket#\')' => '(  .      ,  \'Ticket#\', \'Call#\'  \'MyTicket#\')',
       'A message should have a From: recipient!' => '      :',
-      'Add language' => '  ',
+      'Add user' => '  ',
+      'AdminArea' => '-',
+      'AgentFrontend' => '-',
+      'Article free text' => '  ',
       'Backend' => '',
       'BackendMessage' => ' ',
-      'Change system language setting' => '     ',
+      'Charset' => ' ',
+      'Charsets' => ' ',
       'Create' => '',
       'CustomerUser' => '-',
-      'FAQ' => '  ',
       'Fulltext search' => ' ',
+      'Fulltext search (e. g. "Mar*in" or "Baue*" or "martin+hallo")' => '  ( "Mar*in"  "Baue*"  "martin+hallo")',
       'Handle' => '',
+      'New state' => ' ',
       'New ticket via call.' => '   ',
+      'New user' => ' ',
+      'POP3 Account' => 'POP3 ',
       'Search in' => ' ',
       'Set customer id of a ticket' => '     ',
       'Show all' => '  ',
       'Status defs' => '  ',
-      'System Language Management' => '   ',
+      'Ticket free text' => '  ',
       'Ticket limit:' => '  :',
       'Time till escalation' => '  ',
-      'Update auto response' => '   ',
-      'Update charset' => '   ',
-      'Update group' => '  ',
-      'Update language' => '  ',
-      'Update queue' => '  ',
-      'Update response' => '  ',
-      'Update salutation' => '  ',
-      'Update signature' => '  ',
-      'Update state' => '  ',
-      'Update system address' => '   ',
-      'Update user' => '  ',
-      'With State' => '',
-      'You have to be in the admin group!' => '     admin !',
-      'You have to be in the stats group!' => '     stat !',
+      'With State' => ' ',
       'You need a email address (e. g. customer@example.com) in From:!' => '     ( customer@example.com)   :',
       'auto responses set' => '  ',
+      'search' => '',
+      'search (e. g. 10*5155 or 105658*)' => ' ( 10*5155  105658*)',
       'store' => '',
-      'tickets' => '',
     );
 
     # $$STOP$$
