@@ -2,7 +2,7 @@
 # Kernel/Language/fi.pm - provides fi language translation
 # Copyright (C) 2002 Antti Kmrinen <antti at seu.net>
 # --
-# $Id: fi.pm,v 1.15 2003/04/12 23:03:37 martin Exp $
+# $Id: fi.pm,v 1.21 2004/02/10 00:18:37 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,7 +13,7 @@ package Kernel::Language::fi;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.15 $';
+$VERSION = '$Revision: 1.21 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 # --
 sub Data {
@@ -22,28 +22,32 @@ sub Data {
     my %Hash = ();
 
     # $$START$$
-    # Last translation Sun Apr 13 01:00:15 2003 by 
+    # Last translation Tue Feb 10 01:07:29 2004 by 
 
     # possible charsets
     $Self->{Charset} = ['iso-8859-1', 'iso-8859-15', ];
     # date formats (%A=WeekDay;%B=LongMonth;%T=Time;%D=Day;%M=Month;%Y=Jear;)
     $Self->{DateFormat} = '%D.%M.%Y %T';
     $Self->{DateFormatLong} = '%A %D %B %T %Y';
-    $Self->{DateInputFormat} = '%D.%M.%Y - %T';
+    $Self->{DateInputFormat} = '%D.%M.%Y';
+    $Self->{DateInputFormatLong} = '%D.%M.%Y - %T';
 
     %Hash = (
     # Template: AAABase
       ' 2 minutes' => ' 2 Minuuttia',
       ' 5 minutes' => ' 5 Minuuttia',
       ' 7 minutes' => ' 7 Minuuttia',
+      '(Click here to add)' => '',
       '10 minutes' => '10 Minuuttia',
       '15 minutes' => '15 Minuuttia',
       'AddLink' => 'Lis linkki',
-      'AdminArea' => 'Yllpito',
+      'Admin-Area' => 'Yllpito',
       'agent' => '',
+      'Agent-Area' => '',
       'all' => 'kaikki',
       'All' => 'Kaikki',
       'Attention' => 'Huomio',
+      'before' => '',
       'Bug Report' => 'Lhet bugiraportti',
       'Cancel' => 'Peruuta',
       'change' => 'muuta',
@@ -55,11 +59,13 @@ sub Data {
       'customer' => '',
       'Customer Info' => 'Tietoa asiakkaasta',
       'day' => 'piv',
+      'day(s)' => '',
       'days' => 'piv',
       'description' => 'Selitys',
       'Description' => 'Selitys',
       'Dispatching by email To: field.' => '',
       'Dispatching by selected Queue.' => '',
+      'Don\'t show closed Tickets' => '',
       'Don\'t work with UserID 1 (System account)! Create new users!' => 'Ei toimi kyttjID:ll 1(jrjestelmtunnus). Tee uusia kyttji ',
       'Done' => 'Valmis',
       'end' => 'Loppuun',
@@ -67,6 +73,7 @@ sub Data {
       'Example' => 'Esimerkki',
       'Examples' => 'Esimerkit',
       'Facility' => '',
+      'FAQ-Area' => '',
       'Feature not active!' => 'Ominaisuus ei kytss',
       'go' => 'mene',
       'go!' => 'mene!',
@@ -80,6 +87,7 @@ sub Data {
       'Invalid SessionID!' => 'Virheellinen SessionID',
       'Language' => 'Kieli',
       'Languages' => 'Kielet',
+      'last' => '',
       'Line' => 'Rivi',
       'Lite' => 'Kevyt',
       'Login failed! Your username or password was entered incorrectly.' => '',
@@ -89,7 +97,9 @@ sub Data {
       'minutes' => 'minuuttia',
       'Module' => 'Moduuli',
       'Modulefile' => 'Moduulitiedosto',
+      'month(s)' => '',
       'Name' => 'Nimi',
+      'New Article' => '',
       'New message' => 'Uusi viesti',
       'New message!' => 'Uusi viesti!',
       'No' => 'Ei',
@@ -99,6 +109,7 @@ sub Data {
       'none' => 'ei mitn',
       'none - answered' => 'ei mitn - vastattu',
       'none!' => 'ei mitn!',
+      'Normal' => '',
       'Off' => 'Pois',
       'off' => 'pois',
       'On' => 'Pll',
@@ -108,13 +119,16 @@ sub Data {
       'Please answer this ticket(s) to get back to the normal queue view!' => 'Vastaa thn viestiin saadaksesi se takaisin normaalille jonotuslistalle',
       'Please contact your admin' => 'Ota yhteytt yllpitjsi',
       'please do not edit!' => 'l muokkaa, kiitos!',
+      'Please go away!' => '',
       'possible' => 'Kytss',
+      'Preview' => '',
       'QueueView' => 'Jonotuslistankym',
       'reject' => 'Hylk',
       'replace with' => 'Korvaa',
       'Reset' => 'Tyhjenn',
       'Salutation' => 'Tervehdys',
       'Session has timed out. Please log in again.' => '',
+      'Show closed Tickets' => '',
       'Signature' => 'Allekirjoitus',
       'Sorry' => 'Anteeksi',
       'Stats' => 'Tilastot',
@@ -128,16 +142,20 @@ sub Data {
       'Theme' => 'Ulkoasu',
       'There is no account with that login name.' => 'Kyttjtunnus tuntematon',
       'Timeover' => 'Vanhentuu',
+      'To: (%s) replaced with database email!' => '',
       'top' => 'yls',
       'update' => 'pivit',
+      'Update' => '',
       'update!' => 'pivit!',
       'User' => 'Kyttj',
       'Username' => 'Kyttjnimi',
       'Valid' => 'Kytss',
       'Warning' => 'Varoitus',
+      'week(s)' => '',
       'Welcome to OTRS' => 'Tervetuloa kyttmn OTRS-jrjestelm',
       'Word' => 'Sana',
       'wrote' => 'kirjoittaa',
+      'year(s)' => '',
       'yes' => 'kyll',
       'Yes' => 'Kyll',
       'You got new message!' => 'Sinulla on uusi viesti!',
@@ -164,24 +182,30 @@ sub Data {
       'Follow up notification' => 'Ilmoitus jatkokysymyksist',
       'Frontend' => 'Kyttliittym',
       'Mail Management' => 'Osoitteiden hallinta',
+      'Max. shown Tickets a page in Overview.' => '',
+      'Max. shown Tickets a page in QueueView.' => '',
       'Move notification' => 'Siirr ilmoitus',
       'New ticket notification' => 'Ilmoitus uusista viesteist',
       'Other Options' => 'Muita asetuksia',
+      'PhoneView' => 'Puhelu / Uusi tiketti',
       'Preferences updated successfully!' => 'Asetukset tallennettu onnistuneesti',
       'QueueView refresh time' => 'Jonotusnkymn pivitysaika',
+      'Screen after new ticket' => '',
       'Select your default spelling dictionary.' => '',
       'Select your frontend Charset.' => 'Valitse kyttliittymn kirjaisinasetukset',
       'Select your frontend language.' => 'Valitse kyttliittymn kieli',
       'Select your frontend QueueView.' => 'Valitse kyttliittymsi jonotusnkym',
       'Select your frontend Theme.' => 'Valitse kyttliittymsi ulkoasu',
       'Select your QueueView refresh time.' => 'Valitse jonotusnkymn pivitysaika',
+      'Select your screen after creating a new ticket.' => '',
       'Send me a notification if a customer sends a follow up and I\'m the owner of this ticket.' => 'Lhet ilmoitus jatkokysymyksist, jos olen kyseisen tiketin omistaja',
       'Send me a notification if a ticket is moved into a custom queue.' => 'Lhet minulle ilmoitus, jos tikettej siirretn valitsemiini jonoihin',
       'Send me a notification if a ticket is unlocked by the system.' => 'Lhet minulle ilmoitus, jos jrjestelm poistaa tiketin lukituksen.',
       'Send me a notification if there is a new ticket in my custom queues.' => 'Lhet ilmoitus uusista tiketeist, jotka tulevat valitsemilleni jonotuslistoille',
-      'Show closed tickets.' => '',
-      'Spelling Dictionary' => '',
+      'Show closed tickets.' => 'Nyt suljetut tiketit.',
+      'Spelling Dictionary' => 'Oikolukusanasto',
       'Ticket lock timeout notification' => 'Ilmoitus tiketin lukituksen vanhenemisesta',
+      'TicketZoom' => '',
 
     # Template: AAATicket
       '1 very low' => '1 Erittin alhainen',
@@ -189,7 +213,7 @@ sub Data {
       '3 normal' => '3 Normaali',
       '4 high' => '4 Kiireellinen',
       '5 very high' => '5 Erittin kiireellinen',
-      'Action' => 'Hyvksy',
+      'Action' => 'Tapahtumat',
       'Age' => 'Ik',
       'Article' => 'Artikkeli',
       'Attachment' => 'Liitetiedosto',
@@ -212,7 +236,7 @@ sub Data {
       'high' => 'Kiireellinen',
       'History' => 'Historia',
       'If it is not displayed correctly,' => 'Jos tm ei ny oikein,',
-      'lock' => '',
+      'lock' => 'lukittu',
       'Lock' => 'Lukitse',
       'low' => 'Alhainen',
       'Move' => 'Siirr',
@@ -224,9 +248,9 @@ sub Data {
       'open' => 'avoin',
       'Owner' => 'Omistaja',
       'Pending' => 'Odottaa',
-      'pending auto close+' => '',
-      'pending auto close-' => '',
-      'pending reminder' => '',
+      'pending auto close+' => 'Automaattisulkeminen+',
+      'pending auto close-' => 'Automaattisulkeminen-',
+      'pending reminder' => 'Muistutus',
       'phone' => 'puhelimitse',
       'plain' => 'pelkk teksti',
       'Priority' => 'Prioriteetti',
@@ -240,6 +264,7 @@ sub Data {
       'This is a HTML email. Click here to show it.' => 'Tm shkposti on HTML-muodossa. Klikkaa tst katsoaksesi sit',
       'This message was written in a character set other than your own.' => 'Tm teksti on kirjoitettu eri kirjaisinasetuksilla kuin omasi',
       'Ticket' => 'Tiketti',
+      'Ticket "%s" created!' => '',
       'To' => 'Vastaanottaja',
       'to open it in a new window.' => 'avataksesi se uuteen ikkunaan.',
       'unlock' => 'poista lukitus',
@@ -260,16 +285,14 @@ sub Data {
       'Wed' => 'Ke',
 
     # Template: AdminAttachmentForm
-      'Add attachment' => 'Lis liitetiedosto',
+      'Add' => '',
       'Attachment Management' => 'Liitetiedostojen hallinta',
-      'Change attachment settings' => 'Muuta liitetiedostojen asetuksia',
 
     # Template: AdminAutoResponseForm
       'Add auto response' => 'Lis automaattivastaus',
       'Auto Response From' => 'Automaattivastaus ',
       'Auto Response Management' => 'Automaattivastausten hallinta',
       'Change auto response settings' => 'Muuta automaattivastausten asetuksia',
-      'Charset' => 'Kirjaisinasetus',
       'Note' => 'Huomautus',
       'Response' => 'Vastaa',
       'to get the first 20 character of the subject' => 'nhdksesi ensimmiset 20 kirjainta otsikosta',
@@ -281,35 +304,41 @@ sub Data {
       'Type' => 'Tyyppi',
       'Useable options' => 'Kytettvt asetukset',
 
-    # Template: AdminCharsetForm
-      'Add charset' => 'Lis kirjaisinasetus',
-      'Change system charset setting' => 'Muuta kirjaisinasetuksia',
-      'System Charset Management' => 'Jrjestelmn kirjaisinasetusten hallinta',
-
     # Template: AdminCustomerUserForm
-      'Add customer user' => 'Lis asiakas-kyttj',
-      'Change customer user settings' => 'Muuta asiakas-kyttjn asetuksia',
       'Customer User Management' => 'Asiakas-kyttjien hallinta',
       'Customer user will be needed to to login via customer panels.' => 'Asiakas-kyttjn pit kirjautua Asiakas-liittymst',
+      'Select source:' => '',
+      'Source' => '',
 
     # Template: AdminCustomerUserGeneric
 
+    # Template: AdminCustomerUserGroupChangeForm
+      'Change %s settings' => 'Muuta %s asetuksia',
+      'Customer User <-> Group Management' => '',
+      'Full read and write access to the tickets in this group/queue.' => '',
+      'If nothing is selected, then there are no permissions in this group (tickets will not be available for the user).' => '',
+      'Permission' => 'Kyttoikeus',
+      'Read only access to the ticket in this group/queue.' => '',
+      'ro' => '',
+      'rw' => '',
+      'Select the user:group permissions.' => '',
+
+    # Template: AdminCustomerUserGroupForm
+      'Change user <-> group settings' => 'Vaihda kyttj <-> Ryhmhallinta',
+
     # Template: AdminCustomerUserPreferencesGeneric
 
     # Template: AdminEmail
       'Admin-Email' => 'Yllpidon shkposti',
       'Body' => 'Runko-osa',
       'OTRS-Admin Info!' => '',
-      'Permission' => '',
       'Recipents' => 'Vastaanottajat',
-      'send' => '',
+      'send' => 'lhet',
 
     # Template: AdminEmailSent
       'Message sent to' => 'Viesti lhetetty, vastaanottaja: ',
 
     # Template: AdminGroupForm
-      'Add group' => 'Lis ryhm',
-      'Change group settings' => 'Muuta ryhmn asetuksia',
       'Create new groups to handle access permissions for different groups of agent (e. g. purchasing department, support department, sales department, ...).' => 'Lis uusi kyttjryhm, ett voit mritell kyttoikeuksia useammille eri tukiryhmille (Huolto, Ostot, Markkinointi jne.)',
       'Group Management' => 'Ryhmien hallinta',
       'It\'s useful for ASP solutions.' => 'Tm on hydyllinen ASP-kytss',
@@ -320,17 +349,18 @@ sub Data {
 
     # Template: AdminNavigationBar
       'AdminEmail' => 'Yllpidon shkposti',
-      'AgentFrontend' => 'Tukinkym',
       'Attachment <-> Response' => '',
       'Auto Response <-> Queue' => 'Automaattivastaukset <-> Jonotuslista',
       'Auto Responses' => 'Automaattivastaukset',
-      'Charsets' => 'Kirjaisinasetus',
       'Customer User' => 'Asiakas-kyttj',
+      'Customer User <-> Groups' => '',
       'Email Addresses' => 'Shkpostiosoitteet',
       'Groups' => 'Ryhmt',
       'Logout' => 'Kirjaudu ulos',
       'Misc' => 'Muut',
-      'POP3 Account' => 'POP3 -tunnus',
+      'Notifications' => '',
+      'PostMaster Filter' => '',
+      'PostMaster POP3 Account' => 'PostMaster POP3 -tunnus',
       'Responses' => 'Vastaukset',
       'Responses <-> Queue' => 'Vastaukset <-> Jonotuslista',
       'Select Box' => 'Suodatus',
@@ -339,17 +369,28 @@ sub Data {
       'System' => 'Jrjestelm',
       'User <-> Groups' => 'Kyttj <-> Ryhmt',
 
+    # Template: AdminNotificationForm
+      'Config options (e. g. &lt;OTRS_CONFIG_HttpType&gt;)' => '',
+      'Notification Management' => '',
+      'Notifications are sent to an agent or a customer.' => '',
+      'Options of the current customer user data (e. g. &lt;OTRS_CUSTOMER_DATA_USERFIRSTNAME&gt;)' => '',
+      'Options of the current user who requested this action (e. g. &lt;OTRS_CURRENT_USERFIRSTNAME&gt;)' => '',
+      'Ticket owner options (e. g. &lt;OTRS_OWNER_USERFIRSTNAME&gt;)' => '',
+
     # Template: AdminPOP3Form
-      'Add POP3 Account' => 'Lis POP3 -tunnus',
       'All incoming emails with one account will be dispatched in the selected queue!' => 'Kaikki saapuvat shkpostit lhetetn valitulle jonotuslistalle',
-      'Change POP3 Account setting' => 'Muuta POP3 -asetuksia',
-      'Dispatching' => '',
+      'Dispatching' => 'Lhet',
       'Host' => 'Palvelin',
       'If your account is trusted, the x-otrs header (for priority, ...) will be used!' => '',
       'Login' => 'Kyttjtunnus',
       'POP3 Account Management' => 'POP3 -tunnusten hallinta',
       'Trusted' => 'Hyvksytty',
 
+    # Template: AdminPostMasterFilterForm
+      'Match' => '',
+      'PostMasterFilter Management' => '',
+      'Set' => '',
+
     # Template: AdminQueueAutoResponseForm
       'Queue <-> Auto Response Management' => 'Jonotuslista <-> Automaattivastaushallinta',
 
@@ -358,8 +399,6 @@ sub Data {
     # Template: AdminQueueForm
       '0 = no escalation' => '0 = ei vanhentumisaikaa',
       '0 = no unlock' => '0 = ei lukituksen poistumista',
-      'Add queue' => 'Lis jonotuslista',
-      'Change queue settings' => 'Muuta jonotuslistan asetuksia',
       'Customer Move Notify' => '',
       'Customer Owner Notify' => '',
       'Customer State Notify' => '',
@@ -382,7 +421,6 @@ sub Data {
       'Will be the sender address of this queue for email answers.' => '',
 
     # Template: AdminQueueResponsesChangeForm
-      'Change %s settings' => 'Muuta %s asetuksia',
       'Std. Responses <-> Queue Management' => 'Oletusvastaukset <-> Jonotuslista',
 
     # Template: AdminQueueResponsesForm
@@ -397,14 +435,12 @@ sub Data {
 
     # Template: AdminResponseForm
       'A response is default text to write faster answer (with default text) to customers.' => 'Vastauspohja on oletusteksti, jonka avulla voit nopeuttaa vastaamista asiakkaille',
-      'Add response' => 'Lis vastauspohja',
-      'Change response settings' => 'Muuta vastauspohjan asetuksia',
       'Don\'t forget to add a new response a queue!' => 'l unohda list uutta vastauspohjaa jonotuslistalle.',
+      'Next state' => '',
       'Response Management' => 'Vastauspohjien hallinta',
+      'The current ticket state is' => '',
 
     # Template: AdminSalutationForm
-      'Add salutation' => 'Lis tervehdys',
-      'Change salutation settings' => 'Muuta tervehdysasetuksia',
       'customer realname' => 'kyttjn oikea nimi',
       'for agent firstname' => 'ksittelijn etunimi',
       'for agent lastname' => 'ksittelijn sukunimi',
@@ -421,34 +457,32 @@ sub Data {
       'SQL' => 'SQL',
 
     # Template: AdminSession
+      'Agent' => '',
       'kill all sessions' => 'Tapa kaikki istunnot',
+      'Overview' => '',
+      'Sessions' => '',
+      'Uniq' => '',
 
     # Template: AdminSessionTable
       'kill session' => 'Tapa istunto',
       'SessionID' => 'SessionID',
 
     # Template: AdminSignatureForm
-      'Add signature' => 'Lis allekirjoitus',
-      'Change signature settings' => 'Muuta allekirjoitusasetuksia',
       'Signature Management' => 'Allekirjoitusten hallinta',
 
     # Template: AdminStateForm
-      'Add state' => 'Lis uusi tila',
-      'Change system state setting' => 'Muuta tiketin tila-asetuksia',
+      'See also' => '',
       'State Type' => '',
       'System State Management' => 'Tilamahdollisuuksien mrittminen',
+      'Take care that you also updated the default states in you Kernel/Config.pm!' => '',
 
     # Template: AdminSystemAddressForm
-      'Add system address' => 'Lis jrjestelmn shkpostiosoite',
       'All incoming emails with this "Email" (To:) will be dispatched in the selected queue!' => 'Alle eingehenden Emails mit dem "To:" werden in die ausgewhlte Queue einsortiert.',
-      'Change system address setting' => 'Muuta jrjestelmn shkpostiasetuksia',
       'Email' => 'Shkposti',
       'Realname' => 'Nimi',
       'System Email Addresses Management' => 'Shkpostiosoitteiden mritys',
 
     # Template: AdminUserForm
-      'Add user' => 'Lis kyttj',
-      'Change user settings' => 'Vaihda kyttjn asetuksia',
       'Don\'t forget to add a new user to groups!' => 'l unohda list kyttj ryhmiin!',
       'Firstname' => 'Etunimi',
       'Lastname' => 'Sukunimi',
@@ -456,26 +490,41 @@ sub Data {
       'User will be needed to handle tickets.' => 'Kyttj tarvitaan tikettien ksittelemiseen.',
 
     # Template: AdminUserGroupChangeForm
-      'Change  settings' => '',
+      'create' => '',
+      'move_into' => '',
+      'owner' => '',
+      'Permissions to change the ticket owner in this group/queue.' => '',
+      'Permissions to change the ticket priority in this group/queue.' => '',
+      'Permissions to create tickets in this group/queue.' => '',
+      'Permissions to move tickets into this group/queue.' => '',
+      'priority' => '',
       'User <-> Group Management' => 'Kyttj <-> Ryhmhallinta',
 
     # Template: AdminUserGroupForm
-      'Change user <-> group settings' => 'Vaihda kyttj <-> Ryhmhallinta',
 
     # Template: AdminUserPreferencesGeneric
 
+    # Template: AgentBook
+      'Address Book' => '',
+      'Discard all changes and return to the compose screen' => 'Hylk muutokset ja palaa viestin kirjoitusikkunaan',
+      'Return to the compose screen' => 'Palaa viestin kirjoitusikkunaan',
+      'Search' => '',
+      'The message being composed has been closed.  Exiting.' => '',
+      'This window must be called from compose window' => '',
+
     # Template: AgentBounce
       'A message should have a To: recipient!' => 'Viestiss pit olla vastaanottaja!',
       'Bounce ticket' => 'Delekoi tiketti',
       'Bounce to' => 'Delekoi',
-      'Inform sender' => '',
+      'Inform sender' => 'Informoi lhettj',
       'Next ticket state' => 'Uusi tiketin status',
       'Send mail!' => 'Lhet shkposti!',
       'You need a email address (e. g. customer@example.com) in To:!' => 'Laita vastaanottajakenttn shkpostiosoite!',
       'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations.' => 'Shkposti, tikettinumero "<OTRS_TICKET>" on vlitetty osoitteeseen: "<OTRS_BOUNCE_TO>" . Ota yhteytt kyseiseen osoitteeseen saadaksesi listietoja',
 
     # Template: AgentClose
-      ' (work units)' => '',
+      ' (work units)' => ' (esim. minuutteina)',
+      'A message should have a body!' => '',
       'A message should have a subject!' => 'Viestiss pit olla otsikko!',
       'Close ticket' => 'Sulje tiketti',
       'Close type' => 'Sulkemisen syy',
@@ -484,15 +533,15 @@ sub Data {
       'Note type' => 'Viestityyppi',
       'Options' => 'Asetukset',
       'Spell Check' => 'Oikeinkirjoituksen tarkistus',
-      'Time units' => 'Aikayksikt',
-      'You need to account time!' => '',
+      'Time units' => 'Tyaika',
+      'You need to account time!' => 'Ksittelyaika',
 
     # Template: AgentCompose
-      'A message must be spell checked!' => '',
+      'A message must be spell checked!' => 'Viesti tytyy oikolukea!',
       'Attach' => 'Liite',
       'Compose answer for ticket' => 'Lhet vastaus tikettiin',
-      'for pending* states' => '',
-      'Is the ticket answered' => '',
+      'for pending* states' => 'Automaattisulkeminen tai muistutus',
+      'Is the ticket answered' => 'Onko tikettiin vastattu',
       'Pending Date' => 'Odotuspiv',
 
     # Template: AgentCustomer
@@ -503,17 +552,22 @@ sub Data {
       'Set customer user and customer id of a ticket' => '',
 
     # Template: AgentCustomerHistory
+      'All customer tickets.' => '',
       'Customer history' => 'Asiakkaan historiatiedot',
 
-    # Template: AgentCustomerHistoryTable
-
     # Template: AgentCustomerMessage
       'Follow up' => 'Ilmoitukset',
-      'Next state' => '',
 
     # Template: AgentCustomerView
       'Customer Data' => '',
 
+    # Template: AgentEmailNew
+      'All Agents' => '',
+      'Clear From' => '',
+      'Compose Email' => '',
+      'Lock Ticket' => '',
+      'new ticket' => 'Uusi tiketti',
+
     # Template: AgentForward
       'Article type' => 'Huomautustyyppi',
       'Date' => 'Pivmr',
@@ -527,7 +581,7 @@ sub Data {
       'Value' => '',
 
     # Template: AgentHistoryForm
-      'History of' => '',
+      'History of' => 'Historia:',
 
     # Template: AgentMailboxNavBar
       'All messages' => 'Kaikki viestit',
@@ -546,16 +600,19 @@ sub Data {
       'up' => 'alkuun',
 
     # Template: AgentMailboxTicket
+      '"}' => '',
+      '"}","14' => '',
 
     # Template: AgentMove
       'Move Ticket' => '',
+      'New Owner' => '',
       'New Queue' => '',
-      'New user' => 'Uusi kyttj',
+      'Previous Owner' => '',
+      'Queue ID' => '',
 
     # Template: AgentNavigationBar
       'Locked tickets' => 'Lukitut tiketit',
       'new message' => 'uusi viesti',
-      'PhoneView' => 'Puhelu / Uusi tiketti',
       'Preferences' => 'Kyttjasetukset',
       'Utilities' => 'Etsi',
 
@@ -579,9 +636,6 @@ sub Data {
       'Phone call at %s' => 'Puhelu %s',
 
     # Template: AgentPhoneNew
-      'Clear From' => '',
-      'create' => '',
-      'new ticket' => 'Uusi tiketti',
 
     # Template: AgentPlain
       'ArticleID' => '',
@@ -602,16 +656,11 @@ sub Data {
 
     # Template: AgentPriority
       'Change priority of ticket' => 'Muuta prioriteetti',
-      'New state' => 'Uusi tila',
 
     # Template: AgentSpelling
       'Apply these changes' => 'Hyvksy muutokset',
-      'Discard all changes and return to the compose screen' => 'Hylk muutokset ja palaa viestin kirjoitusikkunaan',
-      'Return to the compose screen' => 'Palaa viestin kirjoitusikkunaan',
       'Spell Checker' => 'Oikeinkirjoituksen tarkistus',
       'spelling error(s)' => 'Kirjoitusvirheit',
-      'The message being composed has been closed.  Exiting.' => '',
-      'This window must be called from compose window' => '',
 
     # Template: AgentStatusView
       'D' => 'A',
@@ -626,6 +675,10 @@ sub Data {
 
     # Template: AgentStatusViewTableNotAnswerd
 
+    # Template: AgentTicketLink
+      'Link' => '',
+      'Link to' => '',
+
     # Template: AgentTicketLocked
       'Ticket locked!' => 'Tiketti lukittu!',
       'Ticket unlock!' => '',
@@ -636,15 +689,27 @@ sub Data {
     # Template: AgentTicketPrintHeader
       'Accounted time' => '',
       'Escalation in' => 'Vanhenee',
-      'printed by' => '',
 
     # Template: AgentUtilSearch
-      'Article free text' => '',
-      'Fulltext search (e. g. "Mar*in" or "Baue*" or "martin+hallo")' => 'Tekstihaku("Etsi esimerkiksi "Mi*a" tai "Petr+Tekrat"',
-      'search' => 'Etsi',
-      'search (e. g. 10*5155 or 105658*)' => 'etsi tikettinumerolla (Esim. 10*5155 or 105658*)',
-      'Ticket free text' => 'Etsi koko tiketist',
+      '(e. g. 10*5155 or 105658*)' => '',
+      '(e. g. 234321)' => '',
+      '(e. g. U5150)' => '',
+      'and' => '',
+      'Customer User Login' => '',
+      'Delete' => '',
+      'Fulltext-Search in Article (e. g. "Mar*in" or "Baue*")' => '',
+      'No time settings.' => '',
+      'Profile' => '',
+      'Result Form' => '',
+      'Save Search-Profile as Template?' => '',
+      'Search-Template' => '',
+      'Select' => '',
+      'Ticket created' => '',
+      'Ticket created between' => '',
       'Ticket Search' => '',
+      'TicketFreeText' => '',
+      'Times' => '',
+      'Yes, save it with name' => '',
 
     # Template: AgentUtilSearchByCustomerID
       'Customer history search' => 'Asiakashistoriahaku',
@@ -652,10 +717,24 @@ sub Data {
       'No * possible!' => 'Jokerimerkki (*) ei kytss !',
 
     # Template: AgentUtilSearchNavBar
+      'Change search options' => '',
       'Results' => 'Hakutulokset',
+      'Search Result' => '',
       'Total hits' => 'Hakutuloksia yhteens',
 
     # Template: AgentUtilSearchResult
+      '"}","15' => '',
+
+    # Template: AgentUtilSearchResultPrint
+
+    # Template: AgentUtilSearchResultPrintTable
+      '"}","30' => '',
+
+    # Template: AgentUtilSearchResultShort
+
+    # Template: AgentUtilSearchResultShortTable
+
+    # Template: AgentUtilSearchResultShortTableNotAnswered
 
     # Template: AgentUtilTicketStatus
       'All closed tickets' => '',
@@ -683,9 +762,10 @@ sub Data {
 
     # Template: AgentZoomHead
       'Free Fields' => '',
-      'Print' => '',
+      'Print' => 'Tulosta',
 
     # Template: AgentZoomStatus
+      '"}","18' => '',
 
     # Template: CustomerCreateAccount
       'Create Account' => 'Luo tunnus',
@@ -693,12 +773,42 @@ sub Data {
     # Template: CustomerError
       'Traceback' => '',
 
+    # Template: CustomerFAQArticleHistory
+      'Edit' => '',
+      'FAQ History' => '',
+
+    # Template: CustomerFAQArticlePrint
+      'Category' => '',
+      'Keywords' => '',
+      'Last update' => '',
+      'Problem' => '',
+      'Solution' => '',
+      'Symptom' => '',
+
+    # Template: CustomerFAQArticleSystemHistory
+      'FAQ System History' => '',
+
+    # Template: CustomerFAQArticleView
+      'FAQ Article' => '',
+      'Modified' => '',
+
+    # Template: CustomerFAQOverview
+      'FAQ Overview' => '',
+
+    # Template: CustomerFAQSearch
+      'FAQ Search' => '',
+      'Fulltext' => '',
+      'Keyword' => '',
+
+    # Template: CustomerFAQSearchResult
+      'FAQ Search Result' => '',
+
     # Template: CustomerFooter
       'Powered by' => '',
 
     # Template: CustomerHeader
       'Contact' => 'Yhteystiedot',
-      'Home' => 'Koti',
+      'Home' => 'Etusivu',
       'Online-Support' => 'Online-tuki',
       'Products' => 'Tuotteet',
       'Support' => 'Tuki',
@@ -715,7 +825,7 @@ sub Data {
 
     # Template: CustomerNavigationBar
       'Create new Ticket' => 'Luo uusi tiketti',
-      'My Tickets' => 'Minun tikettini',
+      'FAQ' => 'FAQ/UKK',
       'New Ticket' => 'Uusi tiketti',
       'Ticket-Overview' => 'Tiketin katselu',
       'Welcome %s' => 'Tervetuloa %s',
@@ -727,6 +837,7 @@ sub Data {
     # Template: CustomerPreferencesPassword
 
     # Template: CustomerStatusView
+      'My Tickets' => 'Minun tikettini',
 
     # Template: CustomerStatusViewTable
 
@@ -737,15 +848,49 @@ sub Data {
     # Template: Error
       'Click here to report a bug!' => 'Klikkaa tst lhettksesi bugiraportti!',
 
+    # Template: FAQArticleDelete
+      'FAQ Delete' => '',
+      'You really want to delete this article?' => '',
+
+    # Template: FAQArticleForm
+      'Comment (internal)' => '',
+      'Filename' => '',
+      'Short Description' => '',
+
+    # Template: FAQArticleHistory
+
+    # Template: FAQArticlePrint
+
+    # Template: FAQArticleSystemHistory
+
+    # Template: FAQArticleView
+
+    # Template: FAQCategoryForm
+      'FAQ Category' => '',
+
+    # Template: FAQLanguageForm
+      'FAQ Language' => '',
+
+    # Template: FAQNavigationBar
+
+    # Template: FAQOverview
+
+    # Template: FAQSearch
+
+    # Template: FAQSearchResult
+
+    # Template: FAQStateForm
+      'FAQ State' => '',
+
     # Template: Footer
       'Top of Page' => '',
 
     # Template: Header
 
     # Template: InstallerBody
-      'Create Database' => '',
-      'Drop Database' => '',
-      'Finished' => '',
+      'Create Database' => 'Luo tietokanta',
+      'Drop Database' => 'Poista tietokanta',
+      'Finished' => 'Valmis',
       'System Settings' => '',
       'Web-Installer' => '',
 
@@ -754,14 +899,14 @@ sub Data {
       'After doing so your OTRS is up and running.' => '',
       'Have a lot of fun!' => '',
       'Restart your webserver' => '',
-      'Start page' => '',
+      'Start page' => 'Aloitussivu',
       'To be able to use OTRS you have to enter the following line in your command line (Terminal/Shell) as root.' => '',
       'Your OTRS Team' => '',
 
     # Template: InstallerLicense
-      'accept license' => '',
-      'don\'t accept license' => '',
-      'License' => '',
+      'accept license' => 'Hyvksy lisenssi',
+      'don\'t accept license' => 'En hyvksy lisenssi',
+      'License' => 'Lisenssi',
 
     # Template: InstallerStart
       'Create new database' => '',
@@ -797,7 +942,8 @@ sub Data {
       'System FQDN' => '',
       'SystemID' => '',
       'Ticket Hook' => '',
-      'Ticket Number Generator' => '',
+      'Ticket Number Generator' => 'Tikettinumeroiden generoija',
+      'Use utf-8 it your database supports it!' => '',
       'Webfrontend' => 'Webnkym',
 
     # Template: Login
@@ -814,15 +960,17 @@ sub Data {
       'URL' => '',
 
     # Template: PrintHeader
+      'printed by' => 'tulostanut: ',
 
     # Template: QueueView
       'All tickets' => 'Tikettej yhteens',
+      'Page' => '',
       'Queues' => 'Jonotuslista',
       'Tickets available' => 'Tikettej avoinna',
       'Tickets shown' => 'Tikettej nkyviss',
 
     # Template: SystemStats
-      'Graphs' => 'Grafiikat',
+      'Graphs' => 'Kuvaajat',
 
     # Template: Test
       'OTRS Test Page' => 'OTRS - Testisivu',
@@ -838,50 +986,33 @@ sub Data {
     # Template: Warning
 
     # Misc
-      '(Click here to add a group)' => '(Klikkaa tst luodaksesi ryhmn)',
-      '(Click here to add a queue)' => '(Klikkaa tst tehdksesi uuden jonotuslistan)',
-      '(Click here to add a response)' => '(Klikkaa tst listksesi vastauspohjan)',
-      '(Click here to add a salutation)' => '(Klikkaa tst listksesi tervehdyksen)',
-      '(Click here to add a signature)' => '(Klikkaa tlt listksesi allekirjoituksen)',
-      '(Click here to add a system email address)' => '(Klikkaa tst listksesi jrjestelmn shkpostiosoitteen)',
-      '(Click here to add a user)' => '(Klikkaa tst listksesi kyttjn',
-      '(Click here to add an auto response)' => '(Klikkaa tst listksesi automaattivastauksen)',
-      '(Click here to add charset)' => 'Klikkaa tst listksesi kirjaisinasetuksen',
-      '(Click here to add language)' => '(Klikkaa tst listksesi uusi kieli)',
-      '(Click here to add state)' => '(Klikkaa tst listksesi uusi status)',
       'A message should have a From: recipient!' => '',
-      'Add language' => 'Lis kieli',
-      'Backend' => '',
-      'BackendMessage' => '',
-      'Change system language setting' => 'Muokkaa jrjestelmn kieliasetuksua',
+      'AgentFrontend' => 'Tukinkym',
+      'Charset' => 'Kirjaisinasetus',
+      'Charsets' => 'Kirjaisinasetus',
       'Create' => 'Luo',
-      'FAQ' => 'FAQ/UKK',
       'Fulltext search' => 'Tekstihaku',
-      'Handle' => '',
+      'Fulltext search (e. g. "Mar*in" or "Baue*" or "martin+hallo")' => 'Tekstihaku("Etsi esimerkiksi "Mi*a" tai "Petr+Tekrat"',
+      'New state' => 'Uusi tila',
       'New ticket via call.' => 'Uusi ',
+      'New user' => 'Uusi kyttj',
+      'Screen after new phone ticket' => '',
       'Search in' => 'Etsi seuraavista:',
+      'Select your screen after creating a new ticket via PhoneView.' => '',
       'Set customer id of a ticket' => 'Aseta tiketin asiakasnumero#',
       'Show all' => 'Yhteens',
       'Status defs' => 'Tikettien tilamritykset',
+      'System Charset Management' => 'Jrjestelmn kirjaisinasetusten hallinta',
       'System Language Management' => 'Jrjestelmn kielen hallinta',
+      'Ticket free text' => 'Etsi koko tiketist',
       'Ticket limit:' => 'Tikettien max mr',
       'Time till escalation' => 'Aikaa jljell maksimi ksittelyaikaan',
-      'Update auto response' => 'Pivit automaattivastaukset',
-      'Update charset' => 'Pivit kirjaisinasetukset',
-      'Update group' => 'Pivit ryhmtiedot',
-      'Update language' => 'Pivit kieli',
-      'Update queue' => 'Pivit jonotuslista',
-      'Update response' => 'Pivit vastauspohja',
-      'Update salutation' => 'Pivit tervehdys',
-      'Update signature' => 'Pivit allekirjoitus',
-      'Update state' => 'Pivit status',
-      'Update system address' => 'Pivit jrjestelmn shkpostiosoitetta',
-      'Update user' => 'Pivit kyttjtiedot',
-      'With State' => '',
       'You have to be in the admin group!' => 'Sinun tytyy olla admin -ryhmss!',
       'You have to be in the stats group!' => 'Sinun tytyy olla stats -ryhmss',
       'You need a email address (e. g. customer@example.com) in From:!' => 'Lhettj -kentss pit olla shkpostiosoite (esim. teppo.testi@esimerkki.fi)',
-      'auto responses set' => '',
+      'auto responses set' => 'Automaattivastaus asetettu',
+      'search' => 'Etsi',
+      'search (e. g. 10*5155 or 105658*)' => 'etsi tikettinumerolla (Esim. 10*5155 or 105658*)',
       'store' => 'tallenna',
       'tickets' => 'tiketti',
     );
