@@ -2,7 +2,7 @@
 # Kernel/Output/HTML/Customer.pm - provides generic customer HTML output
 # Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: Customer.pm,v 1.27 2004/02/19 14:34:03 martin Exp $
+# $Id: Customer.pm,v 1.27.2.3 2004/04/02 13:20:23 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::Output::HTML::Customer;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.27 $';
+$VERSION = '$Revision: 1.27.2.3 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
@@ -34,7 +34,9 @@ sub CustomerLogin {
         Data => $Self->{ConfigObject}->Get('DefaultUsedLanguages'),
         Name => 'Lang',
         SelectedID => $Self->{UserLanguage},
-        OnChange => 'submit()'
+        OnChange => 'submit()',
+        HTMLQuote => 0,
+        LanguageTranslation => 0,
     );
     # get lost password output
     if ($Self->{ConfigObject}->Get('CustomerPanelLostPassword')
@@ -100,7 +102,7 @@ sub CustomerStatusView {
     for (my $i = 1; $i < ($Pages+1); $i++) {
         $Self->{UtilSearchResultCounter}++;
         $Param{PageNavBar} .= " <a href=\"$Self->{Baselink}Action=CustomerTicketOverView".
-         "&StartHit=". (($i-1)*$Param{PageShown}) .= '&SortBy=$Data{"SortBy"}&Order=$Data{"Order"}">';
+         "&StartHit=". (($i-1)*$Param{PageShown}) .= '&SortBy=$Data{"SortBy"}&Order=$Data{"Order"}&ShowClosedTickets=$Data{"ShowClosed"}&Type=$Data{"Type"}">';
          if ((int($Param{StartHit}+$Self->{UtilSearchResultCounter})/$Param{PageShown}) == ($i)) {
              $Param{PageNavBar} .= '<b>'.($i).'</b>';
          }
