@@ -2,7 +2,7 @@
 # Kernel/Output/HTML/Generic.pm - provides generic HTML output
 # Copyright (C) 2001-2003 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: Generic.pm,v 1.102 2004/02/01 21:31:26 martin Exp $
+# $Id: Generic.pm,v 1.102.2.2 2004/04/02 12:46:14 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -21,7 +21,7 @@ use Kernel::Output::HTML::FAQ;
 use Kernel::Output::HTML::Customer;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.102 $';
+$VERSION = '$Revision: 1.102.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 @ISA = (
@@ -310,7 +310,7 @@ sub Output {
     # --
     foreach (1..3) {
         $Output =~ s{
-            \$(Data|Env|Config){"(.+?)"}
+            \$(QData|Data|Env|Config){"(.+?)"}
         }
         {
             if ($1 eq "Data" || $1 eq "Env") {
@@ -322,6 +322,30 @@ sub Output {
                     "";
                 }
             }
+            elsif ($1 eq "QData") {
+                my $Text = $2;
+                if (!defined($Text) || $Text =~ /^","(.+?)$/) {
+                    "";
+                }
+                elsif ($Text =~ /^(.+?)","(.+?)$/) {
+                    if (defined $GlobalRef->{"DataRef"}->{$1}) {
+                        $Self->Ascii2Html(Text => $GlobalRef->{"DataRef"}->{$1}, Max => $2);
+                    }
+                    else {
+                        # output replace with nothing!
+                        "";
+                    }
+                }
+                else {
+                    if (defined $GlobalRef->{"DataRef"}->{$Text}) {
+                        $Self->Ascii2Html(Text => $GlobalRef->{"DataRef"}->{$Text});
+                    }
+                    else {
+                        # output replace with nothing!
+                        "";
+                    }
+                }
+            }
             # replace with
             elsif ($1 eq "Config") {
                 if (defined $Self->{ConfigObject}->Get($2)) {
