@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Ticket::SendArticle.pm - the global email send module
-# Copyright (C) 2003 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: SendArticle.pm,v 1.2 2003/01/15 18:31:47 martin Exp $
+# $Id: SendArticle.pm,v 1.15 2004/01/27 09:26:06 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,12 +13,13 @@ package Kernel::System::Ticket::SendArticle;
 
 use strict;
 use MIME::Words qw(:all);
+use MIME::Entity;
 use Mail::Internet;
 use Kernel::System::StdAttachment;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.2 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
+$VERSION = '$Revision: 1.15 $';
+$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
 sub InitSendArticle {
@@ -41,14 +42,13 @@ sub SendArticle {
     my $ToOrig = $Param{To} || '';
     my $Charset = $Param{Charset} || 'iso-8859-1';
     my $InReplyTo = $Param{InReplyTo} || '';
-    my $RetEmail = $Param{Email};
     my $Loop = $Param{Loop} || 0;
     my $HistoryType = $Param{HistoryType} || 'SendAnswer';
 
     # --
     # check needed stuff
     # --
-    foreach (qw(TicketID UserID From Body Email)) {
+    foreach (qw(TicketID UserID From Body)) {
       if (!$Param{$_}) {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
         return;
@@ -85,55 +85,62 @@ sub SendArticle {
     # build mail ...
     # --
     # do some encode
-    foreach (qw(From To Cc Subject)) {
+    foreach (qw(From To Cc Bcc Subject)) {
         if ($Param{$_}) {
             $Param{$_} = encode_mimewords($Param{$_}, Charset => $Charset) || '';
         }
     }
+    # check bcc
+    if ($Self->{SendmailBcc}) {
+        $Param{Bcc} .= ", $Self->{SendmailBcc}";
+    }
     # build header
     my $Header = {
         From => $Param{From},
         To => $Param{To},
         Cc => $Param{Cc},
-        Bcc => $Self->{SendmailBcc},
+        Bcc => $Param{Bcc},
         Subject => $Param{Subject},
         'Message-ID' => $MessageID,
-        'In-Reply-To' => $InReplyTo,
+        'In-Reply-To:' => $InReplyTo,
+        'References' => $InReplyTo,
         'X-Mailer' => "OTRS Mail Service ($VERSION)",
         'X-Powered-By' => 'OTRS - Open Ticket Request System (http://otrs.org/)',
-        'X-MimeTools' => MIME::Tools->version,
         Organization => $Self->{Organization},
         Type => 'text/plain; charset='.$Charset,
         Encoding => '8bit',
     }; 
     if ($Loop) {
-        $$Header{Precedence} = 'bulk';
+        $$Header{'Precedence:'} = 'bulk';
         $$Header{'X-Loop'} = 'bulk';
     }
     my $Entity = MIME::Entity->build(%{$Header}, Data => $Param{Body});
     # --
     # attachments
     # --
-    if ($Param{UploadFilename}) {
-        # --
-        # add attachments to article
-        # --
-        $Self->WriteArticlePart(
-            Content => $Param{UploadFilename},
-            Filename => $Param{UploadRealFileName},
-            ContentType => $Param{UploadContentType},
-            ArticleID => $Param{ArticleID},
-            UserID => $Param{UserID},
-        );
-        # --
-        # attach file to email
-        # --
-        $Entity->attach(
-            Filename => $Param{UploadRealFileName},
-            Data     => $Param{UploadFilename},
-            Type     => $Param{UploadContentType},
-            Encoding => "base64",
-        );
+    if ($Param{Attach}) {
+        foreach my $Tmp (@{$Param{Attach}}) {
+            my %Upload = %{$Tmp};
+            if ($Upload{Content} && $Upload{Filename}) {
+              # --
+              # add attachments to article
+              # --
+              $Self->WriteArticlePart(
+                %Upload,
+                ArticleID => $Param{ArticleID},
+                UserID => $Param{UserID},
+              );
+              # --
+              # attach file to email
+              # --
+              $Entity->attach(
+                Filename => $Upload{Filename},
+                Data     => $Upload{Content},
+                Type     => $Upload{ContentType},
+                Encoding => "base64",
+              );
+            }
+        }
     }
     # --
     # std attachments
@@ -141,7 +148,7 @@ sub SendArticle {
     if ($Param{StdAttachmentIDs}) {
         foreach my $ID (@{$Param{StdAttachmentIDs}}) {
             my %Data = $Self->{StdAttachmentObject}->StdAttachmentGet(ID => $ID);
-            foreach (qw(FileName ContentType Content)) {
+            foreach (qw(Filename ContentType Content)) {
                 if (!$Data{$_}) {
                     $Self->{LogObject}->Log(
                         Priority => 'error', 
@@ -153,7 +160,7 @@ sub SendArticle {
             # attach file to email
             # --
             $Entity->attach(
-                Filename => $Data{FileName},
+                Filename => $Data{Filename},
                 Data     => $Data{Content},
                 Type     => $Data{ContentType},
                 Encoding => "base64",
@@ -162,9 +169,7 @@ sub SendArticle {
             # add attachments to article
             # --
             $Self->WriteArticlePart(
-                Content => $Data{Content}, 
-                Filename => $Data{FileName},
-                ContentType => $Data{ContentType},
+                %Data,
                 ArticleID => $Param{ArticleID},
                 UserID => $Param{UserID},
             );
@@ -177,16 +182,21 @@ sub SendArticle {
     # --
     # send mail
     # --
-    if (open( MAIL, "|$Self->{Sendmail} '$RetEmail' " )) {
-        my @Mail = ($head->as_string, "\n", $Entity->body_as_string);
-        print MAIL @Mail;
-        close(MAIL);
+    if ($Self->{SendmailObject}->Send(
+        From => $Param{From},
+        To => $Param{To},
+        Cc => $Param{Cc},
+        Bcc => $Param{Bcc},
+        Subject => $Param{Subject},
+        Header => $head->as_string(),
+        Body => $Entity->body_as_string(),
+    )) {
         # -- 
         # write article to fs
         # -- 
         if (!$Self->WriteArticlePlain(
             ArticleID => $Param{ArticleID}, 
-            Email => \@Mail,
+            Email => $head->as_string."\n".$Entity->body_as_string,
             UserID => $Param{UserID})
         ) {
             return; 
@@ -202,16 +212,13 @@ sub SendArticle {
         # log
         # -- 
         $Self->{LogObject}->Log(
+          Priority => 'notice',
           Message => "Sent email to '$ToOrig' from '$Param{From}'. HistoryType => $HistoryType, Subject => $Param{Subject};",
         );
-
         return $Param{ArticleID};
     }
     else {
-         $Self->{LogObject}->Log(
-           Priority => 'error', 
-           Message => "Can't use $Self->{Sendmail}: $!!",
-         );
+         # error
          return;
     }
 }
@@ -221,13 +228,20 @@ sub BounceArticle {
     my %Param = @_;
     my $Time = time();
     my $Random = rand(999999);
-    my $UserID = $Param{UserID} || 0;
     my $From = $Param{From} || '';
     my $To = $Param{To} || '';
     my $ToOrig = $To;
     my $Cc = $Param{Cc} || '';
     my $HistoryType = $Param{HistoryType} || 'Bounce';
-    my $RetEmail = $Param{Email};
+    # --
+    # check needed stuff
+    # --
+    foreach (qw(From To UserID Email)) {
+      if (!$Param{$_}) {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+        return;
+      }
+    }
     # --
     # build bounce mail ...
     # --
@@ -236,35 +250,34 @@ sub BounceArticle {
     # split body && header
     my @EmailPlain = split(/\n/, $Email);
     my $EmailObject = new Mail::Internet(\@EmailPlain);
-
     # --
     # add ReSent header
     # --
     my $HeaderObject = $EmailObject->head();
-    my $NewMessageID = "<$Time.$Random.$Param{TicketID}.0.$UserID\@$Self->{FQDN}>";
+    my $NewMessageID = "<$Time.$Random.$Param{TicketID}.0.$Param{UserID}\@$Self->{FQDN}>";
     my $OldMessageID = $HeaderObject->get('Message-ID') || '??';
     $HeaderObject->replace('Message-ID', $NewMessageID);
     $HeaderObject->replace('ReSent-Message-ID', $OldMessageID);
     $HeaderObject->replace('Resent-To', $To);
     $HeaderObject->replace('Resent-From', $From);
     my $Body = $EmailObject->body();
-
+    my $BodyAsSting = '';
+    foreach (@{$Body}) {
+        $BodyAsSting .= $_."\n";
+    }
     # --
     # pipe all into sendmail
     # --
-    if (open( MAIL, "|$Self->{Sendmail} '$RetEmail' " )) {
-        print MAIL $HeaderObject->as_string;
-        print MAIL "\n";
-        foreach (@{$Body}) {
-            print MAIL $_."\n";
-        }
-        close(MAIL);
-    }
-    else {
-        print STDERR "$!\n";
+    if (!$Self->{SendmailObject}->Send(
+        From => $Param{From},
+        To => $Param{To},
+        Cc => $Param{Cc},
+        Bcc => $Self->{SendmailBcc},
+        Header => $HeaderObject->as_string(),
+        Body => $BodyAsSting,
+    )) {
         return;
     }
-
     # --
     # write history
     # --
@@ -273,7 +286,7 @@ sub BounceArticle {
         ArticleID => $Param{ArticleID},
         HistoryType => $HistoryType,
         Name => "Bounced email to '$To'.",
-        CreateUserID => $UserID,
+        CreateUserID => $Param{UserID},
     );
     return 1;
 }
