@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # index.pl - the global CGI handle file (incl. auth) for OTRS
-# Copyright (C) 2001-2003 Martin Edenhofer <martin+code@otrs.org>
+# Copyright (C) 2001-2004 Martin Edenhofer <martin+code@otrs.org>
 # --
-# $Id: index.pl,v 1.50.2.1 2003/02/11 14:57:43 wiktor Exp $
+# $Id: index.pl,v 1.66 2004/02/13 00:33:58 martin Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -28,8 +28,8 @@ use lib "$Bin/../../Kernel/cpan-lib";
 use strict;
 
 use vars qw($VERSION @INC);
-$VERSION = '$Revision: 1.50.2.1 $';
-$VERSION =~ s/^.*:\s(\d+\.\d+)\s.*$/$1/;
+$VERSION = '$Revision: 1.66 $';
+$VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # --
 # 0=off;1=on;
@@ -54,6 +54,7 @@ use Kernel::System::DB;
 use Kernel::System::Auth;
 use Kernel::System::AuthSession;
 use Kernel::System::User;
+use Kernel::System::Group;
 use Kernel::System::Permission;
 use Kernel::Output::HTML::Generic;
 
@@ -119,7 +120,7 @@ $CommonObject{LayoutObject} = Kernel::Output::HTML::Generic->new(
 # check common objects
 # --
 if (!$CommonObject{DBObject}) {
-    print $CommonObject{LayoutObject}->Header(Title => 'Error!');
+    print $CommonObject{LayoutObject}->Header(Area => 'Core', Title => 'Error!');
     print $CommonObject{LayoutObject}->Error(
         Message => $DBI::errstr,
         Comment => 'Please contact your admin'
@@ -128,7 +129,7 @@ if (!$CommonObject{DBObject}) {
     exit (1);
 }
 if ($CommonObject{ParamObject}->Error()) {
-    print $CommonObject{LayoutObject}->Header(Title => 'Error!');
+    print $CommonObject{LayoutObject}->Header(Area => 'Core', Title => 'Error!');
     print $CommonObject{LayoutObject}->Error(
         Message => $CommonObject{ParamObject}->Error(),
         Comment => 'Please contact your admin'
@@ -140,6 +141,7 @@ if ($CommonObject{ParamObject}->Error()) {
 # create common framework objects 3/3
 # --
 $CommonObject{UserObject} = Kernel::System::User->new(%CommonObject);
+$CommonObject{GroupObject} = Kernel::System::Group->new(%CommonObject);
 $CommonObject{PermissionObject} = Kernel::System::Permission->new(%CommonObject);
 $CommonObject{SessionObject} = Kernel::System::AuthSession->new(%CommonObject);
 # --
@@ -162,7 +164,8 @@ foreach ('$Kernel::Config::Modules::Param', '$Kernel::Config::ModulesCustom::Par
       || $Param->{$Key};
   }
 }
-
+# security check Action Param (replace non word chars)
+$Param{Action} =~ s/\W//g;
 # --
 # check request type
 # --
@@ -170,37 +173,69 @@ if ($Param{Action} eq "Login") {
     # --
     # get params
     # --
-    my $User = $CommonObject{ParamObject}->GetParam(Param => 'User') || '';
-    my $Pw = $CommonObject{ParamObject}->GetParam(Param => 'Password') || '';
+    my $PostUser = $CommonObject{ParamObject}->GetParam(Param => 'User') || '';
+    my $PostPw = $CommonObject{ParamObject}->GetParam(Param => 'Password') || '';
     # --
     # create AuthObject
     # --
     my $AuthObject = Kernel::System::Auth->new(%CommonObject);
-
     # --
     # check submited data
     # --
-    if ( $AuthObject->Auth(User => $User, Pw => $Pw) ) {
+    my $User = $AuthObject->Auth(User => $PostUser, Pw => $PostPw);
+    if ($User) {
         # --
         # get user data
         # --
-        my %UserData = $CommonObject{UserObject}->GetUserData(User => $User);
+        my %UserData = $CommonObject{UserObject}->GetUserData(User => $User, Valid => 1);
         # --
         # check needed data
         # --
         if (!$UserData{UserID} || !$UserData{UserLogin}) {
+            if ($CommonObject{ConfigObject}->Get('AuthModule') eq 'Kernel::System::Auth::LDAP') {
+                # sync user
+                if ($CommonObject{UserObject}->SyncLDAP2Database(User => $User)) {
+                    if ($CommonObject{ConfigObject}->Get('LoginURL')) {
+                        # redirect to alternate login
+                        print $CommonObject{LayoutObject}->Redirect(
+                            ExtURL => $CommonObject{ConfigObject}->Get('LoginURL')."?Reason=AccountActivated",
+                        );
+                    } 
+                    else {
+                        # show error login screen
+                        print $CommonObject{LayoutObject}->Login(
+                            Title => 'First Visit?',
+                            Message => 'Useraccount activated, retry.',
+                            %Param,
+                        );
+                    }
+                }
+                else {
+                    if ($CommonObject{ConfigObject}->Get('LoginURL')) {
+                        # redirect to alternate login
+                        print $CommonObject{LayoutObject}->Redirect(
+                            ExtURL => $CommonObject{ConfigObject}->Get('LoginURL')."?Reason=SystemError",
+                        );
+                    } 
+                    else {
+                        # show error login screen
+                        print $CommonObject{LayoutObject}->Login(
+                            Title => 'First Visit?',
+                            Message => 'Can\'t activate user.',
+                            %Param,
+                        );
+                    }
+                }
+                exit (0);
+            }
             if ($CommonObject{ConfigObject}->Get('LoginURL')) {
-                # --
                 # redirect to alternate login
-                # --
                 print $CommonObject{LayoutObject}->Redirect(
                     ExtURL => $CommonObject{ConfigObject}->Get('LoginURL')."?Reason=SystemError",
                 );
             }
             else {
-                # --
-                # show login screen
-                # ---
+                # show need user data error message
                 print $CommonObject{LayoutObject}->Login(
                     Title => 'Panic!',
                     Message => 'Panic! No UserData!!!',
@@ -217,6 +252,24 @@ if ($Param{Action} eq "Login") {
             Key => 'UserLastLogin',
             Value => time(),
         );
+        # get groups rw
+        my %GroupData = $CommonObject{GroupObject}->GroupMemberList(
+            Result => 'HASH',
+            Type => 'rw',
+            UserID => $UserData{UserID},
+        );
+        foreach (keys %GroupData) {
+            $UserData{"UserIsGroup[$GroupData{$_}]"} = 'Yes';
+        }
+        # get groups ro
+        %GroupData = $CommonObject{GroupObject}->GroupMemberList(
+            Result => 'HASH',
+            Type => 'ro',
+            UserID => $UserData{UserID},
+        );
+        foreach (keys %GroupData) {
+            $UserData{"UserIsGroupRo[$GroupData{$_}]"} = 'Yes';
+        }
         # --
         # create new session id
         # --
@@ -232,7 +285,6 @@ if ($Param{Action} eq "Login") {
               SessionIDCookie => $CommonObject{ParamObject}->SetCookie(
                   Key => $Param{SessionName},
                   Value => $NewSessionID,
-                  Expires => '+24h',
               ),
           },
           SessionID => $NewSessionID, 
@@ -283,7 +335,7 @@ if ($Param{Action} eq "Login") {
 # Logout
 # --
 elsif ($Param{Action} eq "Logout"){
-    if ( $CommonObject{SessionObject}->CheckSessionID(SessionID => $Param{SessionID}) ) {
+    if ($CommonObject{SessionObject}->CheckSessionID(SessionID => $Param{SessionID})) {
         # --
         # get session data
         # --
@@ -298,7 +350,6 @@ elsif ($Param{Action} eq "Logout"){
               SessionIDCookie => $CommonObject{ParamObject}->SetCookie(
                   Key => $Param{SessionName},
                   Value => '',
-                  Expires => '-24d',
               ),
           },
           %CommonObject,
@@ -308,7 +359,7 @@ elsif ($Param{Action} eq "Logout"){
         # --
         # remove session id
         # --
-        if ( $CommonObject{SessionObject}->RemoveSessionID(SessionID => $Param{SessionID}) ) {
+        if ($CommonObject{SessionObject}->RemoveSessionID(SessionID => $Param{SessionID})) {
             if ($CommonObject{ConfigObject}->Get('LogoutURL')) {
                 # --
                 # redirect to alternate login
@@ -377,7 +428,7 @@ elsif ($Param{Action} eq "LostPassword"){
         # --
         print $CommonObject{LayoutObject}->Login(
            Title => 'Login',
-           Message => 'Feature not acitv!',
+           Message => 'Feature not active!',
         );
         exit 0;
     }
@@ -406,7 +457,7 @@ elsif ($Param{Action} eq "LostPassword"){
         # update new password
         $CommonObject{UserObject}->SetPassword(UserLogin => $User, PW => $UserData{NewPW});
         # send notify email
-        my $EmailObject = Kernel::System::EmailSend->new(%CommonObject);
+        my $EmailObject = Kernel::System::Email->new(%CommonObject);
         my $Body = $CommonObject{ConfigObject}->Get('NotificationBodyLostPassword')
           || "New Password is: <OTRS_NEWPW>";
         my $Subject = $CommonObject{ConfigObject}->Get('NotificationSubjectLostPassword')
@@ -414,7 +465,7 @@ elsif ($Param{Action} eq "LostPassword"){
         foreach (keys %UserData) {
             $Body =~ s/<OTRS_$_>/$UserData{$_}/gi;
         }
-        if ($EmailObject->SendNormal(
+        if ($EmailObject->Send(
               To => $UserData{UserEmail},
               Subject => $Subject, 
               Body => $Body)) {
@@ -438,7 +489,18 @@ elsif ($Param{Action} eq "LostPassword"){
 # show login site
 # --
 elsif (!$Param{SessionID}) {
-    if ($CommonObject{ConfigObject}->Get('LoginURL')) {
+    # --
+    # create AuthObject
+    # --
+    my $AuthObject = Kernel::System::Auth->new(%CommonObject);
+    if ($AuthObject->GetOption(What => 'PreAuth')) {
+        # automatic login
+        $Param{RequestedURL} = $CommonObject{LayoutObject}->LinkEncode($Param{RequestedURL});
+        print $CommonObject{LayoutObject}->Redirect(
+            OP => "Action=Login&RequestedURL=$Param{RequestedURL}",
+        );
+    }
+    elsif ($CommonObject{ConfigObject}->Get('LoginURL')) {
         # --
         # redirect to alternate login
         # --
@@ -475,13 +537,27 @@ elsif (eval "require Kernel::Modules::$Param{Action}" && eval '$Kernel::Modules:
               SessionIDCookie => $CommonObject{ParamObject}->SetCookie(
                   Key => $Param{SessionName},
                   Value => '',
-                  Expires => '-24d',
               ),
           },
           %CommonObject,
           %Param,
         );
-        if ($CommonObject{ConfigObject}->Get('LoginURL')) {
+        # --
+        # create AuthObject
+        # --
+        my $AuthObject = Kernel::System::Auth->new(%CommonObject);
+        if ($AuthObject->GetOption(What => 'PreAuth')) {
+            # automatic re-login
+            $Param{RequestedURL} = $CommonObject{LayoutObject}->LinkEncode($Param{RequestedURL});
+print STDERR $CommonObject{LayoutObject}->Redirect(
+                  OP => "?Action=Login&RequestedURL=$Param{RequestedURL}",
+             );
+;
+             print $CommonObject{LayoutObject}->Redirect(
+                  OP => "?Action=Login&RequestedURL=$Param{RequestedURL}",
+             );
+        }
+        elsif ($CommonObject{ConfigObject}->Get('LoginURL')) {
             # --
             # redirect to alternate login
             # --
@@ -544,8 +620,44 @@ elsif (eval "require Kernel::Modules::$Param{Action}" && eval '$Kernel::Modules:
             %Param, 
             %UserData,
         );
-
+        # -- 
+        # module permisson check
+        # --
+        my $Access = 1;
+        my $AccessOk = 0;
+        my %ConfigMap = (
+            'Module::Permission' => 'UserIsGroup',
+            'Module::Permission::Ro' => 'UserIsGroupRo',
+        );
+        foreach my $Map (keys %ConfigMap) {
+          my $Group = '';
+          if ($CommonObject{ConfigObject}->Get($Map)) {
+              $Group = $CommonObject{ConfigObject}->Get($Map)->{$Param{Action}} || '';      }
+          if (ref($Group) eq 'ARRAY') {
+            foreach (@{$Group}) {
+                if ($_ && ($UserData{$ConfigMap{$Map}."[$_]"} && $UserData{$ConfigMap{$Map}."[$_]"} eq 'Yes')) {
+                    $AccessOk = 1;
+                }
+            }
+            if (!$AccessOk) {
+                $Access = 0;
+            }
+          }
+          else {
+            if ($Group && (!$UserData{$ConfigMap{$Map}."[$Group]"} || $UserData{$ConfigMap{$Map}."[$Group]"} ne 'Yes')) {
+                $Access = 0;
+            }
+          }
+        }
+        if (!$Access) {
+            print $CommonObject{LayoutObject}->NoPermission(
+                Message => "You have to be in the a permitted group!",
+            );
+            exit (0);
+        }
+        # --
         # debug info
+        # --
         if ($Debug) {
             $CommonObject{LogObject}->Log(
                 Priority => 'debug',
@@ -560,8 +672,9 @@ elsif (eval "require Kernel::Modules::$Param{Action}" && eval '$Kernel::Modules:
             %Param,
             %UserData,
         );
-
+        # --
         # debug info
+        # --
         if ($Debug) {
             $CommonObject{LogObject}->Log(
                 Priority => 'debug',
